@@ -95,7 +95,7 @@ class RessourceAdmin(admin.ModelAdmin):
             'fields': ('publish', 'priority'),
         }),
         (None, {
-            'fields': ('name', 'image'),
+            'fields': ('name', 'image', 'tags'),
         }),
         (_('File'), {
             'fields': ('file_type', 'file', 'file_url', 'file_weight'), 
